@@ -7,6 +7,7 @@ import time
 from properly_util_python.dynamo_data_utils import DynamoData
 
 from properly_util_python.schemas import UserSchema
+from properly_util_python.dynamo_helper import DynamoHelperBase
 
 
 logger = logging.getLogger()
@@ -18,7 +19,7 @@ class UserAuthHelper:
     OPERATIONS_ROLE_ID = "S4jlPBglYkqccBcWody6hw"
     BASIC_ROLE_ID = "jczqf4GgkEKd1bxtTgpJOg"
 
-    def __init__(self, dynamo_helper):
+    def __init__(self, dynamo_helper: DynamoHelperBase):
         self.dynamo_helper = dynamo_helper
         self.table_helper = TableHelper(self.dynamo_helper)
         self.user_table = self.table_helper.get_table(TableHelper.USER_TABLE_NAME)
@@ -64,20 +65,32 @@ class UserAuthHelper:
         is_email_verified = claims.get("email_verified")
         if is_email_verified is None:
             print("email is verified is none")
-            return None
+            #remove early exit, see note below
+            #return None
 
         #default false
         is_email_verified_bool = False
         if ( isinstance(is_email_verified, bool) and (is_email_verified) ):
             #specifically boolean type and true
+            print("email verified found as boolean true")
             is_email_verified_bool = True
         elif (is_email_verified == "true"):
             #specifically a string containing true
+            print("email verified found as string 'true'")
             is_email_verified_bool = True
 
         if not is_email_verified_bool:
-            #don't accept unconfirmed email
-            return None
+            #Previously: don't accept unconfirmed email
+            #return None
+            #Now: this check is weakened by allowing jwt without email verified explicitly set
+            #reasoning, the connected systems only provide verified emails, but, that could change
+            # facebook : https://stackoverflow.com/a/11847514/7632432
+            # google : https://stackoverflow.com/a/30357942/7632432
+            # amazon : can't confirm without email as currently configured:
+            #           https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-email-phone-verification.html
+            print("strict mode would not pass login")
+            pass
+
 
         user_auth_context = {'auth_id': sub,
                              'auth_email': email}
